.. Copyright 2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Package reahl.web.bootstrap.tables
----------------------------------

.. automodule:: reahl.web.bootstrap.tables


Table
"""""
.. sidebar:: Examples

   - tutorial.tablebootstrap

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. autoclass:: Table
   :members: with_data

DynamicColumn
"""""""""""""

.. autoclass:: DynamicColumn
   :members:

StaticColumn
""""""""""""

.. autoclass:: StaticColumn
   :members:

DataTable
"""""""""

.. autoclass:: DataTable
   :members:

TableLayout
"""""""""""

.. autoclass:: TableLayout
   :members:


Caption
"""""""

.. autoclass:: Caption
   :members:

Thead
"""""

.. autoclass:: Thead
   :members:

Tfoot
"""""

.. autoclass:: Tfoot
   :members:

Tbody
"""""

.. autoclass:: Tbody
   :members:

Tr
""

.. autoclass:: Tr
   :members:

Td
""

.. autoclass:: Td
   :members:

Th
""

.. autoclass:: Th
   :members:

Col
"""

.. autoclass:: Col
   :members:

ColGroup
""""""""

.. autoclass:: ColGroup
   :members:

